@@ -971,7 +971,7 @@ class Database(object):
         elif auto_create is True:
             self.create_collection(collection_name=collection_name, indexes=indexes)
             collection_name = self._prefix_collection_name(collection_name)
-            col = self.dbcollection(collection_name)
+            col = self.db.collection(collection_name)
         else:
             raise CollectionNotFoundError()
 
@@ -1418,8 +1418,10 @@ class Collection(object):
             Generator[CollectionItem]
         """
         
+        if page is None and offset:
+            page = lib.calc_pagination_page_from_offset(offset=offset, per_page=limit)
 
-        if offset is None and page:
+        elif offset is None and page:
             offset = lib.calc_pagination_offset(page=page, per_page=limit)
 
         xql = {
@@ -1427,7 +1429,8 @@ class Collection(object):
             "FILTERS": filters,
             "OFFSET": offset,
             "LIMIT": limit,
-            "SORT": sort
+            "SORT": sort,
+            "PAGE": page
         }
 
         def data_mapper(item): return self.item(item)
