@@ -542,6 +542,17 @@ def calc_pagination_offset(page: int, per_page: int) -> int:
     """
     return 0 if page < 1 else (page - 1) * per_page
 
+def calc_pagination_page_from_offset(offset:int, per_page:int) -> int:
+    """
+    To calculate the pagination page having provided an offset and a per_page
+    
+    Args:
+        - offset:int - The offset 
+        - per_page: total items per page
+    Returns: int
+    """
+    return 1 if offset <= 0 else round((offset / per_page))
+
 
 def gen_pagination(size: int, count: int, page: int, per_page: int) -> dict:
     """
