@@ -25,29 +25,35 @@ AQL_FILTER_OPERATORS = {
     "$LT": "<",  # lesser than
     "$LTE": "<=",  # lesser than or equal
 
-    # IN + NIN
-    # To test if data in (LEFT:str|int) is in the (RIGHT:array)
-    # ie "city:$in": ["charlotte", "atlanta"]
-    # --> u.city in ["charlotte", "atlanta"]
-    "$IN": "IN",
-    "$NIN": "NOT IN",
 
-    # XIN + XNIN
-    # reverse the order of IN+NIN. Can be translated as `contains`
+    # IN + NIN
     # Test if data in (LEFT:array) contains value on (RIGHT:string|int)
     # ie: "__subcollections.something[*].value:$xin": "my-value"
     # --> "my-value" IN __subcollections.something[*].value 
+    "$IN": "IN",
+    "$NIN": "NOT IN",
+
+    # IN + NIN
+    # reverse the order of IN+NIN. Can be translated as `contains`
+    # To test if data in (LEFT:str|int) is in the (RIGHT:array)
+    # ie "city:$in": ["charlotte", "atlanta"]
+    # --> u.city in ["charlotte", "atlanta"]
     "$XIN": "IN",
     "$XNIN": "NOT IN",
 
+
     # LIKE + NOTLIKE
     # right hand in left hand array -> values IN [field.value]
     "$LIKE": "LIKE",  # search
-    "$NLIKE": "NOT LIKE",  # ,
+    "$NLIKE": "NOT LIKE",  # 
+    #TODO:
+    # == for case insensitive ==
+    # "$ILIKE": "",
+    # "$NILIKE": ""
 }
 # reverse operator, where the right hand will point to left hand
-# ie: cities:$xin: 'charlotte' -> 'charlotte' IN cities
-_rev_ops_order = ['$XIN', '$XNIN']
+# ie: cities:$in: 'charlotte' -> 'charlotte' IN cities
+_rev_ops_order = ['$IN', '$NIN']
 
 
 
